<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link  https://rextheme.co
 * @since 1.0.0
 *
 * @package    Checkout_Field_Editor
 * @subpackage Checkout_Field_Editor/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Checkout_Field_Editor
 * @subpackage Checkout_Field_Editor/admin
 * @author     CodeRex <enquiry@coderex.co>
 */
class Checkout_Field_Editor_Admin
{

    /**
     * The ID of this plugin.
     *
     * @since  1.0.0
     * @access private
     * @var    string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since  1.0.0
     * @access private
     * @var    string $version The current version of this plugin.
     */
    private $version;


    public $edit_cf;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * 
     * @since 1.0.0
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        
        add_filter('plugin_action_links_checkout_fields_manager/checkout-fields-editor.php',[ $this, 'cfe_settings_links' ] );
    }

    /**
     * Add settings links to plugin page
     */
    public function cfe_settings_links( $actions ) {
        $url = admin_url( 'admin.php?page=checkout-fields-editor');
        
        $settings = array(
           '<a href="'.$url.'">Settings</a>',
        );
        $actions = array_merge( $actions, $settings );
        return $actions;
      
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since 1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Checkout_Field_Editor_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Checkout_Field_Editor_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        $current_page = get_current_screen()->base;
        if ($current_page == 'woocommerce_page_checkout-fields-editor') {
            wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'assets/css/checkout-field-editor-admin.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . 'select2-css', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css');
        }

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since 1.0.0
     */
    public function enqueue_scripts( $hook )
    {
        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Checkout_Field_Editor_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Checkout_Field_Editor_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        $current_page = get_current_screen()->base;
        if ( $hook == 'woocommerce_page_checkout-fields-editor' ) {
            wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'assets/js/checkout-field-editor-admin.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->plugin_name . 'main-js', plugin_dir_url(__FILE__) . 'assets/js/main.js', array('jquery'), $this->version, true);
            wp_enqueue_script($this->plugin_name . 'select2-js', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js', array('jquery'), $this->version, true);
            wp_localize_script($this->plugin_name . 'main-js', 'tcfdata', array('url' => admin_url('admin-ajax.php'),'ajax_nonce' => wp_create_nonce('cfe_security_nonce'),));
        }

    }

   
 

    /**
     * Cfe_admin_menu
     * Add a sub page under woocommerce
     */
    public function cfe_admin_menu()
    {
        add_submenu_page(
            'woocommerce',
            __('Checkout fields editor', 'checkout-fields-editor'),
            __('Checkout fields editor', 'checkout-fields-editor'),
            'manage_options',
            'checkout-fields-editor', array(
                $this,
                'cfe_display_custom_checkout_page')
        );
    }

    public function cfe_display_custom_checkout_page()
    {
        include_once CHECKOUT_FIELD_EDITOR_PLUGIN_DIR . '/admin/partials/checkout-field-editor-admin-display.php';
    }

    /**
     * Cfe_delete_data
     * Delete field
     */
    function cfe_delete_data()
    {
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        $data = sanitize_text_field($_GET['data']);
        $section = sanitize_text_field($_GET['section']);
        
        if($section == 'billing'){
            $response = $this->cfe_delete_billing_field($data);
        }elseif($section == 'shipping'){
            $response = $this->cfe_delete_shipping_field($data);
        }elseif($section == 'additional'){
            $response = $this->cfe_delete_additional_field($data);
        }else{
            $response = 'fail';
        }

        if($response == 'success_billing'){
            echo 'success_billing';
            wp_die();
        }else if($response == 'success_shipping'){
            echo 'success_shipping';
            wp_die();
        }else if($response == 'success_additional'){
            echo 'success_additional';
            wp_die();
        }
        else{
            echo 'fail';
            wp_die();
        }
    }

    /**
     * Cfe_delete_billing_field
     */
    function cfe_delete_billing_field($data){
        $get_default_data = get_option('cfe_wc_billing_default_fields');
        $get_data = get_option('cfe_wc_billing_fields');
     
        $count = 0;
        foreach ($get_data as $key => $value) {
            if ($value['delete'] == 0) {
                $count++;
            }
        }
        //check if shipping field is not fully empty
        if($count > 1){
            if (isset($get_default_data[$data]) || isset($get_data[$data])) {
                if (isset($get_default_data[$data])) {
                    $get_data[$data]['delete'] = 1;
                    $get_data[$data]['enable'] = 0;
                } else {
                    unset($get_data[$data]);
                }
                update_option('cfe_wc_billing_fields', $get_data);
                return 'success_billing'; 
            }
        }else {
            return 'fail';
        }
    }

    /**
     * Cfe_delete_shipping_field
     */
    function cfe_delete_shipping_field($data){
        $get_default_data = get_option('cfe_wc_shipping_default_fields');
        $get_data = get_option('cfe_wc_shipping_fields');
        $count = 0;
        foreach ($get_data as $key => $value) {
            if ($value['delete'] == 0) {
                $count++;
            }
        }
        //check if shipping field is not fully empty
        if($count > 1){
            if (isset($get_default_data[$data]) || isset($get_data[$data])) {
                if (isset($get_default_data[$data])) {
                    $get_data[$data]['delete'] = 1;
                    $get_data[$data]['enable'] = 0;
                } else {
                    unset($get_data[$data]);
                }
                update_option('cfe_wc_shipping_fields', $get_data);
                return 'success_shipping'; 
            }
        }else {
            return 'fail';
        }
    }

    /**
     * Cfe_delete_additional_field
     */
    function cfe_delete_additional_field($data){
        $get_data = get_option('cfe_wc_additional_fields');

        $count = 0;
        foreach ($get_data as $key => $value) {
            if ($value['delete'] == 0) {
                $count++;
            }
        }
        //check if shipping field is not fully empty
        if ($count > 1) {
            if ($data == 'order_comments') {
                $get_data['order_comments']['delete'] = 1;
                $get_data['order_comments']['enable'] = 0;
                update_option('cfe_wc_additional_fields', $get_data);
                
            } else {
                unset($get_data[$data]);
                update_option('cfe_wc_additional_fields', $get_data);
                
            }
            return 'success_additional';
        } else {
            return 'fail';
            
        }
    }

    /**
     * Cfe_restore_default
     * Restore all field
     */
    function cfe_restore_default()
    {
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        $section = sanitize_text_field($_GET['data']);
        if ($section == 'all_restore') {
            $get_default_data = get_option('cfe_wc_billing_default_fields');
            update_option('cfe_wc_billing_fields', $get_default_data);

            $get_default_data = get_option('cfe_wc_shipping_default_fields');
            update_option('cfe_wc_shipping_fields', $get_default_data);

            $get_default_data = get_option('cfe_wc_additional_default_fields');
            update_option('cfe_wc_additional_fields', $get_default_data);
            echo "success";
            
        }else if( $section == 'billing' || $section == 'shipping' || $section == 'additional'){
            $get_default_data = get_option('cfe_wc_'.$section.'_default_fields');
            update_option('cfe_wc_'.$section.'_fields', $get_default_data);
            echo "success_".$section;
        }else{
            echo "fail";
        } 
        wp_die();
    }



    /**
     * Cfe_wc_edit_field
     * Edit billing and shipping field
     */
    function cfe_wc_edit_field()
    {
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        $data = sanitize_text_field($_GET['data']);
        $type = sanitize_text_field($_GET['type']);
        if ($type == 'billing') {
            $this->cfe_wc_edit_billing_field($data);
        }elseif($type == 'shipping'){
            $this->cfe_wc_edit_shipping_field($data);
        }else{
            $this->cfe_wc_edit_additional_field($data);
        }
    }

    /**
     * Cfe_wc_edit_billing_field
     */
    public function cfe_wc_edit_billing_field($data){
        $get_data_default = get_option('cfe_wc_billing_default_fields');
        $get_data_edit = get_option('cfe_wc_billing_fields');
        $this->cfe_wc_send_json_data($data,$get_data_default,$get_data_edit);
    }

    /**
     * Cfe_wc_edit_shipping_field
     */
    public function cfe_wc_edit_shipping_field($data){
        $get_data_default = get_option('cfe_wc_shipping_default_fields');
        $get_data_edit = get_option('cfe_wc_shipping_fields');
        $this->cfe_wc_send_json_data($data,$get_data_default,$get_data_edit);
    }

    /**
     * Cfe_wc_edit_additional_field
     */
    public function cfe_wc_edit_additional_field($data) {
        $get_data_default = get_option('cfe_wc_additional_default_fields');
        $get_data_edit = get_option('cfe_wc_additional_fields');
        $this->cfe_wc_send_json_data($data,$get_data_default,$get_data_edit);
        
    }

    /**
     * Cfe_wc_send_json_data
     * For edit field
     */
    public function cfe_wc_send_json_data($data,$get_data_default,$get_data_edit) {
        
        if (isset($get_data_default[$data])) {
           
            $editData = array(
                'index' => $data,
                'data' => $get_data_edit[$data]
            );
            
            echo json_encode($editData);
        } elseif( isset($get_data_edit[$data]) ) {
            
            $editData = array(
                'index' => 'custom',
                'data' => $get_data_edit[$data]
            );
            echo json_encode($editData);
        }else{
           
            echo 'fail';
        }
        wp_die();
    }

    
    /**
     * Cfe_change_required_option
     * Change require option for billing,shipping and additional fields
     */
    function cfe_change_required_option()
    {
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        $id = sanitize_text_field($_GET['id']);
        $type = sanitize_text_field($_GET['type']);
        $get_data = get_option('cfe_wc_'.$type.'_fields');
        if(isset($get_data[$id])){
            if ($get_data[$id]['required'] == true) {
                $get_data[$id]['required'] = false;
            } else {
                $get_data[$id]['required'] = true;
            }
            update_option('cfe_wc_'.$type.'_fields', $get_data);
            
            $response = [
                'status' => 'success',
                'data' => $get_data[$id]['label']
            ];
            wp_send_json($response);
           
        }else{
            $response = [
                'status' => 'fail',
                'data' => null
            ];
            wp_send_json($response);
        }
        wp_die();
    }


    /**
     * Cfe_change_enable_option
     * Change enable option for billing,shipping and additional fields
     */
    function cfe_change_enable_option()
    {
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        $id = sanitize_text_field($_GET['id']);
        $type = sanitize_text_field($_GET['type']);
        $get_data = get_option('cfe_wc_'.$type.'_fields');
        if(isset($get_data[$id])){
            if ($get_data[$id]['enable'] == true) {
                $get_data[$id]['enable'] = 0;
            } else {
                $get_data[$id]['enable'] = 1;
            }
            update_option('cfe_wc_'.$type.'_fields', $get_data);
            $response = [
                'status' => 'success',
                'data' => $get_data[$id]['label']
            ];
            wp_send_json($response);
           
        }else{
            $response = [
                'status' => 'fail',
                'data' => null
            ];
            wp_send_json($response);
        }
        
        wp_die();
        
    }

    /**
     * Cfe_add_data
     */
    public function cfe_add_data(){
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        if(isset($_POST['type'] )){
            $cf['type'] = sanitize_text_field($_POST['type']);
        }else{
            echo 'fail';
            wp_die();
        }
        
        if(isset($_POST['label'])){
            $cf['label'] = sanitize_text_field($_POST['label']);
        }else{
            echo 'fail';
            wp_die();
        }

        if(isset($_POST['name'])){
            $_POST['name'] = str_replace(' ','_',$_POST['name']);
           
            $cf['name'] = sanitize_text_field($_POST['name']);
        }else{
            echo 'fail';
            wp_die();
        }

        if(isset($_POST['placeholder'])){
            $cf['placeholder'] = sanitize_text_field($_POST['placeholder']);
        }else{
            $cf['placeholder'] = null;
        }
        
        if(isset($_POST['default'])){
            $cf['default'] = sanitize_text_field($_POST['default']);
        }else{
            $cf['default'] = null;
        }

        $cf['delete'] = 0;

        if(isset($_POST['validate'])){
            $cf['validate'] = $_POST['validate'];
        }else{
            $cf['validate'] = null;
        }
       
        if( ($_POST['type'] == 'select' || $_POST['type'] == 'radio')  && isset($_POST['options']) && isset($_POST['option_text']) ){
            $number = count($_POST['options']);
            if( $number > 0 ){
                for($i = 0; $i< $number; $i++){
                    if($_POST['options'] != '' && $_POST['option_text'] != ''){
                        $option_value = str_replace(' ', '_', $_POST['options'][$i]);
                        $cf['option_text'][$i] =  sanitize_text_field($_POST['option_text'][$i]);
                        $cf['option_value'][$i] =  $option_value;
                    }    
                }
            }else{
                echo 'fail';
                wp_die();
            }
        }
        $cf['class'] = array('my-field-class form-row-wide');
        if( isset($_POST['required']) && $_POST['required'] == 1 ){
            $cf['required'] = true;
        }else{
            $cf['required'] = false;
        }

        if(isset($_POST['show']) && $_POST['show'] == 1){
            $cf['show'] = 1;
        }else{
            $cf['show'] = 0;
        }

        if(isset($_POST['enable']) && $_POST['enable'] == 1){
            $cf['enable'] = 1;
        }else{
            $cf['enable'] = 0;
        }
        // additional field add
        if($_POST['hidden_field'] == 'custom'){
            $get_data = get_option( 'cfe_wc_additional_fields');
            if($get_data){
                if(!(in_array($_POST['name'], $get_data))){
                    $get_data[$_POST['name']] = $cf;
                    update_option( 'cfe_wc_additional_fields', $get_data );
                }else{ 
                    echo 'exist';
                    wp_die();
                }
            }else{
                $get_e_data[$_POST['name']] = $cf;
                update_option( 'cfe_wc_additional_fields', $get_e_data );
            }
            echo 'success_additional';
            wp_die();

        }

        // billing field add
        if($_POST['hidden_field'] == 'billing' ){
            $get_billing_data = get_option( 'cfe_wc_billing_default_fields');
            $get_billing_updated_data = get_option( 'cfe_wc_billing_fields');
            if($get_billing_updated_data){
               
                if(!isset($get_billing_data[$_POST['name']]) && !isset($get_billing_updated_data[$_POST['name']]) ){
                    $get_billing_updated_data[$_POST['name']] = $cf;
                    update_option( 'cfe_wc_billing_fields', $get_billing_updated_data );
                   
                }else{
                    echo 'exist';
                    wp_die();
                }

                echo 'success_billing';
                wp_die();
            }else{
                $get_billing_updated_data[$_POST['name']] = $cf;
                update_option( 'cfe_wc_billing_fields', $get_billing_updated_data );

                echo 'success_billing';
                wp_die();
            } 
            echo 'fail';
            wp_die();

        }

        // shipping field add
        if($_POST['hidden_field'] == 'shipping'){
            $get_shipping_data = get_option( 'cfe_wc_shipping_default_fields');
            $get_shipping_updated_data = get_option( 'cfe_wc_shipping_fields');
            if($get_shipping_updated_data){
                if(!isset($get_shipping_data[$_POST['name']]) && !isset($get_shipping_updated_data[$_POST['name']])){
                    $get_shipping_updated_data[$_POST['name']] = $cf;
                    update_option( 'cfe_wc_shipping_fields', $get_shipping_updated_data );

                    echo 'success_shipping';
                    wp_die();
                }
                else{
                    echo 'exist';
                    wp_die();
                }
            }else{
                $get_shipping_updated_data[$_POST['name']] = $cf;
                update_option( 'cfe_wc_shipping_fields', $get_shipping_updated_data );

                echo 'success_shipping';
                wp_die();
            }

            echo 'fail';
            wp_die();

        }
        echo 'fail';
        wp_die();

    }




    /**
     * Cfe_update_data
     */
    public function cfe_update_data(){
        check_ajax_referer( 'cfe_security_nonce', 'security' );
        
        if(!isset($_POST['cf_edit_name'])){
            echo 'fail';
            wp_die();
        }else{
            $_POST['cf_edit_name'] = str_replace(' ','_',$_POST['cf_edit_name']);
        }
        if(isset($_POST['cf_edit_type'])){
            $this->edit_cf['type'] = sanitize_text_field($_POST['cf_edit_type']);
        }else{
            $this->edit_cf['type'] = null;
        }
    
        if(isset($_POST['cf_edit_label'])){
            $this->edit_cf['label'] = sanitize_text_field($_POST['cf_edit_label']);
        }else{
            $this->edit_cf['label'] = null;
        }
    
        if(isset($_POST['cf_edit_placeholder'])){
            $this->edit_cf['placeholder'] = sanitize_text_field($_POST['cf_edit_placeholder']);
        }else{
            $this->edit_cf['placeholder'] = null;
        }
    
        if(isset($_POST['cf_edit_default'])){
            $this->edit_cf['default'] = sanitize_text_field($_POST['cf_edit_default']);
        }else{
            $this->edit_cf['default'] = null;
        }

        if(isset($_POST['cf_edit_required']) && $_POST['cf_edit_required'] == 1){
            $this->edit_cf['required'] = true;
        }else{
            $this->edit_cf['required'] = false;
        }
        
        if(isset($_POST['cf_edit_show']) && $_POST['cf_edit_show'] == 1){
            $this->edit_cf['show'] = 1;
        }else{
            $this->edit_cf['show'] = 0;
        }
        
        if(isset($_POST['cf_edit_enable']) && $_POST['cf_edit_enable'] == 1){
            $this->edit_cf['enable'] = 1;
        }else{
            $this->edit_cf['enable'] = 0;
        }
        
        if(isset($_POST['edit_validate'])){
            
            $this->edit_cf['validate'] = $_POST['edit_validate'];
        }else{
            $this->edit_cf['validate'] = null;
        }
        
        
        if(isset($_POST['cf_edit_type_option']) && isset($_POST['cf_edit_type_option_text'])){
            $number = count($_POST['cf_edit_type_option']);
            if( $number > 0 ){
                for($i = 0; $i< $number; $i++){
                    if($_POST['cf_edit_type_option'] != '' && $_POST['cf_edit_type_option_text'] != ''){
                        $option_value = str_replace(' ', '_', $_POST['cf_edit_type_option'][$i]);
                        $this->edit_cf['option_text'][$i] =  $_POST['cf_edit_type_option_text'][$i];
                        $this->edit_cf['option_value'][$i] =  $option_value;
                    }
                }
            }else{
                echo __('please enter option value with option text','checkout-fields-editor');
            }
        }
    
        $this->edit_cf['delete'] = 0;
        $this->edit_cf['class'] = array('form-row-wide');
        

                if(isset($_POST['cf_hidden_value']) && $_POST['cf_hidden_value'] == 'custom'){
                    
                    
                    $get_data_billing = get_option( 'cfe_wc_billing_fields');
                    $get_data_shipping = get_option( 'cfe_wc_shipping_fields');
                    $get_data_additional = get_option( 'cfe_wc_additional_fields');
    
                    if(isset($_POST['cf_hidden_type']) && $_POST['cf_hidden_type'] == 'billing'){
                        if($get_data_billing){
                            
                            if(isset($get_data_billing[$_POST['cf_hidden_index']])){
                                unset($get_data_billing[$_POST['cf_hidden_index']]);
                                $get_data_billing[$_POST['cf_edit_name']] = $this->edit_cf;
                                update_option( 'cfe_wc_billing_fields', $get_data_billing );
                                echo 'success_billing';
                                wp_die(); 
                            }
                        }else{
                            $get_e_data = get_option( 'cfe_wc_billing_default_fields');
                            if(isset($get_e_data[$_POST['cf_hidden_index']])){
                                unset($get_e_data[$_POST['cf_hidden_index']]);
                                $get_e_data[$_POST['cf_edit_name']] = $this->edit_cf;
                                update_option( 'cfe_wc_billing_fields', $get_e_data );

                                echo 'success_billing';
                                wp_die(); 
                            }
                        } 
                        echo 'fail';
                        wp_die();          
                    }
    
                    if(isset($_POST['cf_hidden_type']) && $_POST['cf_hidden_type'] == 'shipping'){
                        if($get_data_shipping){
                            if(isset($get_data_shipping[$_POST['cf_hidden_index']])){
                                unset($get_data_shipping[$_POST['cf_hidden_index']]);
                                $get_data_shipping[$_POST['cf_edit_name']] = $this->edit_cf;
                                update_option( 'cfe_wc_shipping_fields', $get_data_shipping );

                                echo 'success_shipping';
                                wp_die(); 
                            }
                    
                        }else{
                            $get_e_data = get_option( 'cfe_wc_shipping_default_fields');
                            if(isset($get_e_data[$_POST['cf_hidden_index']])){
                                unset($get_e_data[$_POST['cf_hidden_index']]);
                                $get_e_data[$_POST['cf_edit_name']] = $this->edit_cf;
                                update_option( 'cfe_wc_shipping_fields', $get_e_data );

                                echo 'success_shipping';
                                wp_die(); 
                            }
                        } 
                        echo 'fail';
                        wp_die();
                    }
    
                    if(isset($_POST['cf_hidden_type']) && $_POST['cf_hidden_type'] == 'additional'){
                       
                        if($get_data_additional){
                            
                            if(isset($get_data_additional[$_POST['cf_hidden_index']])){
                                unset($get_data_additional[$_POST['cf_hidden_index']]);
                                $get_data_additional[$_POST['cf_edit_name']] = $this->edit_cf;
                                update_option( 'cfe_wc_additional_fields', $get_data_additional );
                                echo 'success_additional';
                                wp_die();
                            }
                    
                        }else{
                            $get_e_data = get_option( 'cfe_wc_additional_default_fields');
                            if(isset($get_e_data[$_POST['cf_hidden_index']])){
                                unset($get_data_additional[$_POST['cf_hidden_index']]);
                                $get_e_data[$_POST['cf_edit_name']] = $this->edit_cf;
                                update_option( 'cfe_wc_additional_fields', $get_e_data );
                                echo 'success_additional';
                                wp_die();
                            }
                        } 
                        echo 'fail';
                        wp_die();
                    }
                    echo 'fail';
                    wp_die();
    
                }elseif(isset($_POST['cf_hidden_value']) && $_POST['cf_hidden_value'] == 'default'){
 
                    if(isset($_POST['cf_hidden_type']) && isset($_POST['cf_hidden_index']) && $_POST['cf_hidden_type'] == 'billing'){
                        $get_data = get_option( 'cfe_wc_billing_fields');
                        unset($get_data[$_POST['cf_hidden_index']['placeholder']]);
                        unset($get_data[$_POST['cf_hidden_index']['label']]);
                        unset($get_data[$_POST['cf_hidden_index']['required']]);
                        unset($get_data[$_POST['cf_hidden_index']['show']]);
                        unset($get_data[$_POST['cf_hidden_index']['enable']]);
                        unset($get_data[$_POST['cf_hidden_index']['name']]);
    
    
                        $get_data[$_POST['cf_hidden_index']]['placeholder'] = $this->edit_cf['placeholder'];
                        $get_data[$_POST['cf_hidden_index']]['name'] = $this->edit_cf['name'];
                        $get_data[$_POST['cf_hidden_index']]['label'] = $this->edit_cf['label'];
                        $get_data[$_POST['cf_hidden_index']]['required'] = $this->edit_cf['required'];
                        $get_data[$_POST['cf_hidden_index']]['show'] = $this->edit_cf['show'];
                        $get_data[$_POST['cf_hidden_index']]['enable'] = $this->edit_cf['enable'];
                        $get_data[$_POST['cf_hidden_index']]['validate'] = $this->edit_cf['validate'];
                        $get_data[$_POST['cf_hidden_index']]['default'] = $this->edit_cf['default'];
                        
                        
                        update_option( 'cfe_wc_billing_fields', $get_data );
                        echo 'success_billing';
                        wp_die();
                    }
    
                    if(isset($_POST['cf_hidden_type']) && isset($_POST['cf_hidden_index']) && $_POST['cf_hidden_type'] == 'shipping'){
                        $get_data = get_option( 'cfe_wc_shipping_fields');
                        unset($get_data[$_POST['cf_hidden_index']['placeholder']]);
                        unset($get_data[$_POST['cf_hidden_index']['label']]);
                        unset($get_data[$_POST['cf_hidden_index']['required']]);
                        unset($get_data[$_POST['cf_hidden_index']['show']]);
                        unset($get_data[$_POST['cf_hidden_index']['enable']]);
                        unset($get_data[$_POST['cf_hidden_index']['name']]);
    
    
                        $get_data[$_POST['cf_hidden_index']]['placeholder'] = $this->edit_cf['placeholder'];
                        $get_data[$_POST['cf_hidden_index']]['name'] = $this->edit_cf['name'];
                        $get_data[$_POST['cf_hidden_index']]['label'] = $this->edit_cf['label'];
                        $get_data[$_POST['cf_hidden_index']]['required'] = $this->edit_cf['required'];
                        $get_data[$_POST['cf_hidden_index']]['show'] = $this->edit_cf['show'];
                        $get_data[$_POST['cf_hidden_index']]['enable'] = $this->edit_cf['enable'];
                        $get_data[$_POST['cf_hidden_index']]['validate'] = $this->edit_cf['validate'];
                        $get_data[$_POST['cf_hidden_index']]['default'] = $this->edit_cf['default'];
                        
                        
                        update_option( 'cfe_wc_shipping_fields', $get_data );
                        echo 'success_shipping';
                        wp_die();
                    }
                    if(isset($_POST['cf_hidden_type']) && isset($_POST['cf_hidden_index']) && $_POST['cf_hidden_type'] == 'additional'){
                        $get_data = get_option( 'cfe_wc_additional_fields');
    
                        unset($get_data[$_POST['cf_hidden_index']['placeholder']]);
                        unset($get_data[$_POST['cf_hidden_index']['label']]);
                        unset($get_data[$_POST['cf_hidden_index']['required']]);
                        unset($get_data[$_POST['cf_hidden_index']['show']]);
                        unset($get_data[$_POST['cf_hidden_index']['enable']]);
    
    
                        $get_data[$_POST['cf_hidden_index']]['placeholder'] = $this->edit_cf['placeholder'];
                        $get_data[$_POST['cf_hidden_index']]['label'] = $this->edit_cf['label'];
                        $get_data[$_POST['cf_hidden_index']]['required'] = $this->edit_cf['required'];
                        $get_data[$_POST['cf_hidden_index']]['show'] = $this->edit_cf['show'];
                        $get_data[$_POST['cf_hidden_index']]['enable'] = $this->edit_cf['enable'];
                        $get_data[$_POST['cf_hidden_index']]['validate'] = $this->edit_cf['validate'];
                        $get_data[$_POST['cf_hidden_index']]['default'] = $this->edit_cf['default'];
                        $get_data[$_POST['cf_hidden_index']]['name'] = $this->edit_cf['name'];
                        update_option( 'cfe_wc_additional_fields', $get_data );

                        echo 'success_additional';
                        wp_die();
                    }
                    echo 'fail';
                    wp_die();
    
                }else{
                    echo 'fail';
                    wp_die();
                    
                }
                echo 'fail';
                wp_die();  
    }

    function cfe_admin_redirect() {
        if (get_option('cfe_do_activation_redirect', false)) {
            delete_option('cfe_do_activation_redirect');
             exit( wp_redirect(admin_url( 'admin.php?page=checkout-fields-editor' ) ) );
        }
    }  
}
