<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link    https://rextheme.com/
 * @since   1.0.0
 * @package Checkout_Fields_Editor
 *
 * @wordpress-plugin
 * Plugin Name:       Checkout Field Editor - Checkoutify
 * Plugin URI:        https://rextheme.com/checkoutify/
 * Description:       Customize your Checkout fields easily for a smooth checkout process - edit existing fields, add new custom fields, change field parameters and more.
 * Version:           1.0.0
 * Author:            RexTheme
 * Author URI:        https://rextheme.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       checkout-fields-editor
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}

if ( ! defined( 'CFE_FILE' ) ) {
    define('CFE_FILE', __FILE__);
}

if ( ! defined( 'CFE_BASE' ) ) {
    define('CFE_BASE', plugin_basename(CFE_FILE));
}
if(!defined('CHECKOUT_FIELD_EDITOR_PLUGIN_DIR')){
    define('CHECKOUT_FIELD_EDITOR_PLUGIN_DIR',plugin_dir_path(__FILE__));
}
if(!defined('CHECKOUT_FIELD_EDITOR_PLUGIN_URL')){
    define('CHECKOUT_FIELD_EDITOR_PLUGIN_URL',plugins_url()."/checkout-fields-editor");
}


/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'CHECKOUT_FIELD_EDITOR_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-checkout-field-editor-activator.php
 */
function activate_checkout_field_editor() {
    // check if woocommerce plugin is active or not.. if active checkout-field-editor will active otherwise not

    require_once plugin_dir_path( __FILE__ ) . 'includes/class-checkout-field-editor-activator.php';
    Checkout_Field_Editor_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-checkout-field-editor-deactivator.php
 */
function deactivate_checkout_field_editor() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-checkout-field-editor-deactivator.php';
    Checkout_Field_Editor_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_checkout_field_editor' );
register_deactivation_hook( __FILE__, 'deactivate_checkout_field_editor' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-checkout-field-editor.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since 1.0.0
 */
function run_checkout_field_editor() {

    $plugin = new Checkout_Field_Editor();
    $plugin->run();

    new CFE_Activation_Check( 'woocommerce/woocommerce.php', __FILE__, '1.0', 'checkout-fields-editor' );
}

run_checkout_field_editor();



/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_checkout_field_editor_checkoutify() {
    if ( ! class_exists( 'Appsero\Client' ) ) {
        require_once __DIR__ . '/appsero/src/Client.php';
    }
    $client = new Appsero\Client( '18e1cafd-a8b0-48b1-b202-8fb3b3da11de', 'Checkout Field Editor - Checkoutify', __FILE__ );
    // Active insights
    $client->insights()->init();
}

appsero_init_tracker_checkout_field_editor_checkoutify();