<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link  https://rextheme.co
 * @since 1.0.0
 *
 * @package    Checkout_Field_Editor
 * @subpackage Checkout_Field_Editor/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Checkout_Field_Editor
 * @subpackage Checkout_Field_Editor/public
 * @author     CodeRex <enquiry@coderex.co>
 */
class Checkout_Field_Editor_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since  1.0.0
	 * @access private
	 * @var    string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since  1.0.0
	 * @access private
	 * @var    string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
     *
	 * @param string    $plugin_name       The name of the plugin.
	 * @param string    $version    The version of this plugin.
     *
     * @since 1.0.0

     * @return void
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Checkout_Field_Editor_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Checkout_Field_Editor_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/checkout-field-editor-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Checkout_Field_Editor_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Checkout_Field_Editor_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/checkout-field-editor-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
     * Add custom checkout field for additional section
     * 
     * @param array checkout for field 
    */
    function cfe_add_custom_checkout_field( $checkout ) {
        $get_custom_data = get_option( 'cfe_wc_additional_fields');
      
       
        if($get_custom_data){
            
            foreach($get_custom_data as $key=>$gcd){
                
                if( !('order_comments' == $key )){
                        if($gcd['enable'] == 1){

                            $cfe_option = array();
                                if( $gcd['type'] == 'radio' || $gcd['type'] == 'select'){
                            
                            
                                    for ($i=0; $i < count($gcd['option_text']); $i++) { 
                                        if( $gcd['option_text'][$i] != '' && $gcd['option_value'][$i] != ''){
                                        
                                     
                                           $option_value = str_replace(' ', '_', $gcd['option_value'][$i]);
                                           
                                           $cfe_option[$option_value] = $gcd['option_text'][$i];
                                        }
                                        
                                    }
                                
                            }
                            if( (isset($gcd['type'])) && ($gcd['type'] == 'radio' || $gcd['type'] == 'select' || $gcd['type'] == 'textarea' || $gcd['type'] == 'checkbox')){
                                
                                if( $gcd['type'] == 'radio' || $gcd['type'] == 'checkbox'){
                                    echo '<div >';
                                        woocommerce_form_field( isset($gcd['name']), array(
                                            'type'          => ($gcd['type']),
                                            'class'         =>  array('form-row-wide'),
                                            'label'         => $gcd['label'],
                                            'placeholder'   => $gcd['placeholder'],
                                            'required'      => $gcd['required'],
                                            'options'       =>  $cfe_option,
                                            'default'       =>  $gcd['default'],
                                            'validate'      =>  $gcd['validate']
                                            ), $checkout->get_value( isset($gcd['name'] )));
                        
                                    echo '</div>';
                                }elseif(isset($gcd['name']) && $gcd['name'] == 'textarea'){
                                    $default_select = array(" " => "--select--");
                                    $new_arr = array_merge($default_select, $cfe_option);
                                    echo '<div >';
                                        woocommerce_form_field( isset($gcd['name']), array(
                                            'type'          => $gcd['type'],
                                            'class'         => array('form-row-wide'),
                                            'label'         => $gcd['label'],
                                            'placeholder'   => $gcd['placeholder'],
                                            'required'      => $gcd['required'],
    
                                            'default'       =>  $gcd['default'],
                                            'validate'      =>  $gcd['validate']
                                            ), $checkout->get_value( isset($gcd['name'] )));
                            
                                    echo '</div>';
                                }else{
                                    $default_select = array(" " => "--select--");
                                    $new_arr = $default_select+$cfe_option;
                                    echo '<div >';
                                    if($gcd['type']){
                                        woocommerce_form_field( isset($gcd['name']), array(
                                            'type'          => $gcd['type'],
                                            'class'         => array('form-row-wide'),
                                            'label'         => $gcd['label'],
                                            'placeholder'   => $gcd['placeholder'],
                                            'required'      => $gcd['required'],
                                            'options'       =>    $new_arr,
                                            'default'       =>  $gcd['default'],
                                            'validate'      =>  $gcd['validate']
                                            ), $checkout->get_value( isset($gcd['name'] )));
                                    }else{
                                        woocommerce_form_field( isset($gcd['name']), array(
                                            
                                            'class'         => array('form-row-wide'),
                                            'label'         => $gcd['label'],
                                            'placeholder'   => $gcd['placeholder'],
                                            'required'      => $gcd['required'],
                                            'options'       =>    $new_arr,
                                            'default'       =>  $gcd['default'],
                                            'validate'      =>  $gcd['validate']
                                            ), $checkout->get_value( isset($gcd['name'] )));
                                    }
                                        
                            
                                    echo '</div>';
                                }
                                
                            }else{
                                echo '<div >';
                                if($gcd['type']){
                                    woocommerce_form_field( isset($gcd['name']), array(
                                        'type'          => $gcd['type'],
                                        'class'         => array('form-row-wide'),
                                        'label'         => $gcd['label'],
                                        'placeholder'   => $gcd['placeholder'],
                                        'required'      => $gcd['required'],
                                        
                                        'default'       =>  $gcd['default'],
                                        'validate'      =>  $gcd['validate']
                                        ), $checkout->get_value( isset($gcd['name'] )));
                                }else{
                                    woocommerce_form_field( isset($gcd['name']), array(
                                        
                                        'class'         => array('form-row-wide'),
                                        'label'         => $gcd['label'],
                                        'placeholder'   => $gcd['placeholder'],
                                        'required'      => $gcd['required'],
                                        
                                        'default'       =>  $gcd['default'],
                                        'validate'      =>  $gcd['validate']
                                        ), $checkout->get_value( isset($gcd['name'] )));
                                }
                                echo '</div>';
                            }
                        }
                }
                
            }
        }
   
	}

	
	/**
     * Update the order meta with field value
     * 
     * @param int order_id for update order meta by order id
    */
   
    function cfe_custom_checkout_field_update_order_meta( $order_id ) {

        $get_custom_data = get_option( 'cfe_wc_additional_fields');
        $get_billing_data = get_option( 'cfe_wc_billing_fields');

        $shipping_updated_field = get_option( 'cfe_wc_shipping_fields');

        if ($get_custom_data) {
            foreach($get_custom_data as $get_custom_data){
                update_post_meta( $order_id, $get_custom_data['name'], sanitize_text_field( $_POST[$get_custom_data['name']] ) );
            }
            
        }

        if($get_billing_data){
            foreach($get_billing_data as $key => $value){
                update_post_meta( $order_id, $key, sanitize_text_field( $_POST[$value['name']] ) );
            }
        }

        if($shipping_updated_field){
            foreach($shipping_updated_field as $key => $value){
                update_post_meta( $order_id, $key, sanitize_text_field( $_POST[$value['name']] ) );
            }
        }
	}
	
	/**
     * Cfe_display_additional_field_custom
     * Display additional field value on the order edit page
     * 
     * @param array order for get order_id
     */
    
    function cfe_display_additional_field_custom($order){
        $get_custom_data = get_option( 'cfe_wc_additional_fields');
        if ($get_custom_data) {
          
            foreach($get_custom_data as $gccd=>$value){
                if($value['show'] == 1){
                    echo '<p><strong>'.(esc_attr($value['label'])).':</strong > ' . get_post_meta( $order->get_id(), esc_attr($gccd), true ) . '</p>';
                }
        
            }
        }

    }

    /**
     * Display shipping field value on the order edit page
     * 
     * @param array order for get order_id
     */
    function cfe_display_shipping_field_custom($order){
        $get_shipping_data = get_option( 'cfe_wc_shipping_fields');
        $get_shipping_default_data = get_option( 'cfe_wc_shipping_default_fields');
        
        $key_array = array();
        foreach($get_shipping_default_data as $key=> $avlue){
            array_push($key_array,$key);
        }
        if($get_shipping_data){
            foreach($get_shipping_data as $gccd => $value){
                    if(!(in_array($gccd,$key_array))){
                        if($value['show'] == 1){
                            echo '<p><strong>'.esc_attr($value['label']).':</strong> ' . get_post_meta( $order->get_id(), esc_attr($gccd), true ) . '</p>';
                        }
                    }
             
        
            }
        }
    }
    
    /**
     * Cfe_display_billing_field_custom
     * Display billing field value on the order edit page
     * 
     * @param array order for get order_id
     */
    function cfe_display_billing_field_custom($order){
        $get_billing_data = get_option( 'cfe_wc_billing_fields');
        $get_billing_default_data = get_option( 'cfe_wc_billing_default_fields');
        
        $key_array = array();
        if(is_array($get_billing_default_data)){
            foreach($get_billing_default_data as $key=> $value){
                array_push($key_array,$key);
            }
        }
        if(is_array($get_billing_data)){
            
            foreach($get_billing_data as $gccd => $value){
                
               
                    if(!(in_array($gccd,$key_array))){
                        if($value['show'] == 1){
                            echo '<p><strong>'.esc_attr($value['label']).':</strong> ' . get_post_meta( $order->get_id(), esc_attr($gccd), true ) . '</p>';
                            
                        }
                    }
             
        
            }
        }
    }

    /**
     * Process the checkout notice for additional field
     */
    function cfe_custom_checkout_field_process() {
        $get_custom_data = get_option( 'cfe_wc_additional_fields');
        if(is_array($get_custom_data)){
            foreach($get_custom_data as $gccd){
                if($gccd['required'] == true && $gccd['enable'] == 1){
                    if ( ! $_POST[$gccd['name']] || $_POST[$gccd['name']] == " "){
                        wc_add_notice('Please enter something into this '.$gccd['label'].' field.', 'error' );
                    }   

                }
            }
        }
    }


    /**
     * Cfe_add_fields
     * Add billing,shipping field in checkout page
     * 
     * @param array fields of all fields
     */
    function cfe_add_fields( $fields ) {

        /**
         * For additional
         */
        $get_additional_data = get_option( 'cfe_wc_additional_fields');
        
        if(isset($get_additional_data['order_comments'])){
            if($get_additional_data['order_comments']['enable'] == 0){
                unset($fields['order']['order_comments']);
            }
        }
        
        /**
         * For shipping
         */
        $shipping_default_field = get_option( 'cfe_wc_shipping_default_fields');
        $shipping_updated_field = get_option( 'cfe_wc_shipping_fields');
        $shipping_updated_field_check = get_option( 'cfe_wc_shipping_fields');
        
        foreach($shipping_updated_field as $key => $buf){
            
            if( $buf['enable'] == 1){
                
                $cfe_option = array();
                if( $buf['type'] == 'radio' || $buf['type'] == 'select'){
                    for ($i=0; $i < count($buf['option_text']); $i++) { 
                        if( $buf['option_text'][$i] != '' && $buf['option_value'][$i] != ''){
                            $option_value = str_replace(' ', '_', $buf['option_value'][$i]);
                            $cfe_option[$option_value] = $buf['option_text'][$i];
                        } 
                    }
                    
                }
                if(isset($shipping_default_field[$key]) != isset($shipping_updated_field_check[$key])){

                        $default_select = array(" " => "--select--");
                        
                            if($buf['type'] == 'select'){
                                
                                $fields['shipping'][$key] = array(
                                    'type'      => $buf['type'],
                                    'label'     => $buf['label'],
                                    'placeholder'   => $buf['placeholder'],
                                    'required'  => $buf['required'],
                                    'class'     => array('form-row-wide'),  
                                    'clear'     => true,
                                    'validate' => $buf['validate'],
                                    'default' => $buf['default'],
                                    'options'       => $default_select+$cfe_option,
                                );

                            }elseif($buf['type'] == 'radio' ){
                            
                                $fields['shipping'][$key] = array(
                                    'type'      => $buf['type'],
                                    'label'     => $buf['label'],
                                    'placeholder'   => $buf['placeholder'],
                                    'required'  => $buf['required'],
                                    'class'     => array('form-row-wide','checkout-radio'),  
                                    'clear'     => true,
                                    'validate'  => $buf['validate'],
                                    'default'   => $buf['default'],
                                    'options'   => $cfe_option,
                                );
                            }
                            else{
                                if($buf['type']){
                                    $fields['shipping'][$key] = array(
                                        'type'      => $buf['type'],
                                        'label'     => $buf['label'],
                                        'placeholder'   => $buf['placeholder'],
                                        'required'  => $buf['required'],
                                        'class'     => array('form-row-wide'),  
                                        'clear'     => true,
                                        'default'   => $buf['default'],
                                        'validate' => $buf['validate']
                                    );
                                }else{
                                    $fields['shipping'][$key] = array(
                                        'label'     => $buf['label'],
                                        'placeholder'   => $buf['placeholder'],
                                        'required'  => $buf['required'],
                                        'class'     => array('form-row-wide'),  
                                        'clear'     => true,
                                        'default'   => $buf['default'],
                                        'validate'  => $buf['validate']
                                    );
                                }
                                
                    }
                }else{
                    if($buf['type']){
                        $fields['shipping'][$key] = array(
                            'type'      => $buf['type'],
                            'label'     => $buf['label'],
                            'placeholder'   => $buf['placeholder'],
                            'required'  => $buf['required'],
                            'class'     => array('form-row-wide'),  
                            'clear'     => true,
                            'default' => $buf['default'],
                            'validate' => $buf['validate']
                        );
                    }else{
                        $fields['shipping'][$key] = array(
                            'label'     => $buf['label'],
                            'placeholder'   => $buf['placeholder'],
                            'required'  => $buf['required'],
                            'class'     => array('form-row-wide'),  
                            'clear'     => true,
                            'default' => $buf['default'],
                            'validate' => $buf['validate']
                        );
                    }
                }

            }else{
                unset($fields['shipping'][$key]);
            }
        }
    
        /**
         * For billing
         */
        $billing_default_field = get_option( 'cfe_wc_billing_default_fields');
        $billing_updated_field = get_option( 'cfe_wc_billing_fields');
        $billing_updated_field_check = get_option( 'cfe_wc_billing_fields');

        
        foreach($billing_updated_field as $key => $buf){
            // if($key != 'billing_country' && $key != 'billing_city'){
                if($buf['enable'] == 1){
                    $cfe_option = array();
                    if( $buf['type'] == 'radio' || $buf['type'] == 'select'){
                
                            
                        for ($i=0; $i < count($buf['option_text']); $i++) { 
                            if( $buf['option_text'][$i] != '' && $buf['option_value'][$i] != ''){
                            
                        
                            $option_value = str_replace(' ', '_', $buf['option_value'][$i]);
                            
                            $cfe_option[$option_value] = $buf['option_text'][$i];
                            }
                            
                        }
                        
                    
                    }
                    
                    if(isset($billing_default_field[$key]) != isset($billing_updated_field_check[$key])){
                        $default_select = array(" " => "--select--");
                        
                            if( $buf['type'] == 'select'){
                                
                                $fields['billing'][$key] = array(
                                    'type'      => $buf['type'],
                                    'label'     => $buf['label'],
                                    'placeholder'   => $buf['placeholder'],
                                    'required'  => $buf['required'],
                                    'class'     => array('form-row-wide'),  
                                    'clear'     => true,
                                    'validate'  => $buf['validate'],
                                    'default'   => $buf['default'],
                                    'options'    => $default_select+$cfe_option,
                                );

                            }elseif($buf['type'] == 'radio' || $buf['type'] == 'checkbox'){
                                
                                $fields['billing'][$key] = array(
                                    'type'      => $buf['type'],
                                    'label'     => $buf['label'],
                                    'placeholder'   => $buf['placeholder'],
                                    'required'  => $buf['required'],
                                    'class'     => array('form-row-wide','checkout-radio'),  
                                    'clear'     => true,
                                    'validate'  => $buf['validate'],
                                    'default'   => $buf['default'],
                                    'options'   => $cfe_option,
                                );
                            }
                            else if($buf['type'] == 'textarea'){
                            
                                echo '<p>';
                                        woocommerce_form_field( $buf['name'], array(
                                            'type'          => ($buf['type']),
                                            'class'         =>  array('form-row-wide'),
                                            'label'         => $buf['label'],
                                            'placeholder'   => $buf['placeholder'],
                                            'required'      => $buf['required'],
                                        
                                            'default'       =>  $buf['default'],
                                            'validate'      =>  $buf['validate']
                                            ), $fields['billing'][$key] );
                        
                                    echo '</p>';    
                            
                            }
                                else{
                                    if($buf['type']){
                                        
                                        $fields['billing'][$key] = array(
                                            'type'      => $buf['type'],
                                            'label'     => $buf['label'],
                                            'placeholder'   => $buf['placeholder'],
                                            'required'  => $buf['required'],
                                            'class'     => array('form-row-wide'),  
                                            'clear'     => true,
                                            'default' => $buf['default'],
                                            'validate' => $buf['validate']
                                        );
                                    }else{
                                        $fields['billing'][$key] = array(
                                            'label'     => $buf['label'],
                                            'placeholder'   => $buf['placeholder'],
                                            'required'  => $buf['required'],
                                            'class'     => array('form-row-wide'),  
                                            'clear'     => true,
                                            'default' => $buf['default'],
                                            'validate' => $buf['validate']
                                        ); 
                                    }
                            }
                        

                            
                    }else{
                            
                            
                            if($buf['type']){
                                        
                                $fields['billing'][$key] = array(
                                    'type'      => $buf['type'],
                                    'label'     => $buf['label'],
                                    'placeholder'   => $buf['placeholder'],
                                    'required'  => $buf['required'],
                                    'class'     => array('form-row-wide'),  
                                    'clear'     => true,
                                    'default' => $buf['default'],
                                    'validate' => $buf['validate']
                                );
                            }else{
                                $fields['billing'][$key] = array(
                                    'label'     => $buf['label'],
                                    'placeholder'   => $buf['placeholder'],
                                    'required'  => $buf['required'],
                                    'class'     => array('form-row-wide'),  
                                    'clear'     => true,
                                    'default' => $buf['default'],
                                    'validate' => $buf['validate']
                                ); 
                            }
                        }
                }else{
                    unset($fields['billing'][$key]);
                }
        }
        
        return $fields;
    }
}
